@@ -24,8 +24,7 @@
 /*-----------------------------------------------------------------------------
                                    Includes
 -----------------------------------------------------------------------------*/
-
-#ifndef _XOPEN_SOURCE
+#if !defined(_XOPEN_SOURCE) || (_XOPEN_SOURCE - 0) < 500
 #define _XOPEN_SOURCE 500 /* posix 2001, mkstemp */
 #endif
 
@@ -1595,7 +1594,7 @@ HDRL_OMP(omp parallel for if (nr > s))
         cpl_matrix_delete(lfrom);
         cpl_matrix_delete(lto);
         if (lerr != CPL_ERROR_NONE) {
-HDRL_OMP(omp critical(hdrlwcserror))
+HDRL_OMP(omp critical(hdrl_hdrlwcserror))
             err = lerr;
         }
     }
