@@ -515,7 +515,7 @@ cpl_error_code naco_imagelist_load_diff(cpl_imagelist * self,
 
         /* Find next off-frame - and perhaps also the next on-frame */
         for (; ioff < nfiles; ioff++) {
-            cpl_boolean is_off;
+            cpl_boolean is_off = CPL_FALSE; /* Init to avoid gcc-warning */
 
             skip_if(naco_framelist_get_state(onofflist, ioff, CPL_FALSE,
                                                   &is_off, onoffkeys));
@@ -537,7 +537,7 @@ cpl_error_code naco_imagelist_load_diff(cpl_imagelist * self,
             if (ion == ioff) ion++; /* No need to check an off-frame */
             for (; ion < nfiles; ion++) {
 
-                cpl_boolean is_on;
+                cpl_boolean is_on = CPL_FALSE; /* Init to avoid gcc-warning */
 
                 skip_if(naco_framelist_get_state(onofflist, ion, CPL_TRUE,
                                                       &is_on, onoffkeys));
