@@ -137,11 +137,13 @@ static int naco_img_dark(cpl_frameset            * framelist,
     /* Retrieve input parameters */
     rej_bord = naco_parameterlist_get_string(parlist, RECIPE_STRING, NACO_PARAM_REJBORD);
     skip_if (0);
-    skip_if (sscanf(rej_bord, "%d %d %d %d",
-                    &naco_img_dark_config.rej_left,
-                    &naco_img_dark_config.rej_right,
-                    &naco_img_dark_config.rej_bottom,
-                    &naco_img_dark_config.rej_top) != 4);
+    skip_if_ne(sscanf(rej_bord, "%d %d %d %d",
+                      &naco_img_dark_config.rej_left,
+                      &naco_img_dark_config.rej_right,
+                      &naco_img_dark_config.rej_bottom,
+                      &naco_img_dark_config.rej_top), 4,
+               "number(s) in string parameter (%s): \"%s\"",
+               CPL_XSTRINGIFY(NACO_PARAM_REJBORD), rej_bord);
 
     naco_img_dark_config.hot_thresh =
         naco_parameterlist_get_double(parlist, RECIPE_STRING, NACO_PARAM_HOT_LIM);
