@@ -518,7 +518,9 @@ static cpl_image ** naco_img_jitter_saa(cpl_imagelist    * imlist,
                                       NACO_PARAM_XCORR);
     bug_if (sval == NULL);
 
-    skip_if (sscanf(sval, "%d %d %d %d", &sx, &sy, &mx, &my) != 4);
+    skip_if_ne(sscanf(sval, "%d %d %d %d", &sx, &sy, &mx, &my), 4,
+               "number(s) in string parameter (%s): \"%s\"",
+               CPL_XSTRINGIFY(NACO_PARAM_XCORR), sval);
 
     combine_string = naco_parameterlist_get_string(parlist, RECIPE_STRING,
                                                    NACO_PARAM_COMBINE);
@@ -539,8 +541,9 @@ static cpl_image ** naco_img_jitter_saa(cpl_imagelist    * imlist,
                                       NACO_PARAM_REJ_HILO);
     bug_if (sval == NULL);
 
-    skip_if (sscanf(sval, "%d %d", &rej_low, &rej_high) != 2);
-
+    skip_if_ne(sscanf(sval, "%d %d", &rej_low, &rej_high), 2,
+               "number(s) in string parameter (%s): \"%s\"",
+               CPL_XSTRINGIFY(NACO_PARAM_REJ_HILO), sval);
     
     /* Get the offsets estimation of each input file pair */
     cpl_msg_info(cpl_func, "Get the offsets estimation");
@@ -764,7 +767,10 @@ static cpl_error_code naco_img_jitter_qc_apertures(cpl_propertylist * qclist,
     bug_if(0);
 
     /* Compute the FHWM of the detected apertures */
+    CPL_DIAG_PRAGMA_PUSH_IGN(-Wdeprecated-declarations);
     fwhms = cpl_apertures_get_fwhm(combined, aperts);
+    CPL_DIAG_PRAGMA_POP;
+
     if (fwhms == NULL) {
         cpl_msg_warning(cpl_func, "Could not compute any FWHMs of the "
                           "apertures in the combined image");
