@@ -147,19 +147,24 @@ static int naco_img_twflat(cpl_frameset            * framelist,
     sval = naco_parameterlist_get_string(parlist, RECIPE_STRING,
                                          NACO_PARAM_REJBORD);
     skip_if (0);
-    skip_if (sscanf(sval, "%d %d %d %d",
-                    &naco_img_twflat_config.rej_left,
-                    &naco_img_twflat_config.rej_right,
-                    &naco_img_twflat_config.rej_bottom,
-                    &naco_img_twflat_config.rej_top) != 4);
+    skip_if_ne(sscanf(sval, "%d %d %d %d",
+                      &naco_img_twflat_config.rej_left,
+                      &naco_img_twflat_config.rej_right,
+                      &naco_img_twflat_config.rej_bottom,
+                      &naco_img_twflat_config.rej_top), 4,
+               "number(s) in string parameter (%s): \"%s\"",
+               CPL_XSTRINGIFY(NACO_PARAM_REJBORD), sval);
 
     /* --t */
     sval = naco_parameterlist_get_string(parlist, RECIPE_STRING,
                                          NACO_PARAM_BPMTHRES);
     skip_if (0);
-    skip_if (sscanf(sval, "%lg %lg",
-                    &naco_img_twflat_config.low_thresh,
-                    &naco_img_twflat_config.high_thresh) !=2 );
+    skip_if_ne(sscanf(sval, "%lg %lg",
+                      &naco_img_twflat_config.low_thresh,
+                      &naco_img_twflat_config.high_thresh), 2,
+               "number(s) in string parameter (%s): \"%s\"",
+               CPL_XSTRINGIFY(NACO_PARAM_BPMTHRES), sval);
+
     /* --prop */
     naco_img_twflat_config.prop_flag
         = naco_parameterlist_get_bool(parlist, RECIPE_STRING, NACO_PARAM_PROPFIT);
